==> flutter_conscent_plugin-0.1.3.tar.gz: lib/webviews.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter_conscent_plugin/EmbeddedSubscribe.dart';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import '../Model/APIMode.dart';
import 'ConscentInitializer.dart';

void main() {
  runApp(
    MaterialApp(
      home: WebViewApps(isWoman: true),
    ),
  );
}

class WebViewApps extends StatefulWidget {
  String tiersId;
  bool isWoman;

  WebViewApps({this.tiersId = '', required this.isWoman, super.key});

  @override
  State<WebViewApps> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewApps> {
  String? loginId;
  String ar = "availFreeTrial=true%20";
  late String fn;

  late WebViewController _webViewController;

  final GlobalKey<RefreshIndicatorState> _refreshIndicatorKey =
      GlobalKey<RefreshIndicatorState>();

  final webViewKey = GlobalKey<_WebViewAppStates>();

  @override
  void initState() {
    _refreshIndicatorKey.currentState?.show();

    const Icon(Icons.refresh);
    if (mounted) {
      getLoginChallengeId();
    }

    if (widget.isWoman) {
      fn = ar;
    } else {
      fn = "";
    }

    super.initState();
  }

  dynamic dataMain;

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      return sessionId;
    }
    return '';
  }

  dynamic dataMains;
  Future<void> getPstss(String sessionId) async {
    final prefs = await SharedPreferences.getInstance();

    sessionId = prefs.getString('sessionId') ?? "sessionId";

    String sessionIds = prefs.getString('sessionId').toString();

    final uri = Uri.parse(
        '${APIMode.BASE_URL}api/v1/subscription/access?sessionId=$sessionId&clientId=${ConscentInitializer.mClientId}');

    var response = await http.get(uri);

    if (response.statusCode == 200) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;

      if (mounted) {
        Navigator.pop(context, {"response": responseString});
      }
    }
  }

  JavascriptChannel _javascriptChannel() {
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          if (message.message == 'loginSuccess') {
            String sessionId = await getSessionID(loginId!);
            getPstss(sessionId);
          } else if (message.message == 'changeplan') {
            Navigator.pop(context);
          }
        });
  }

  @override
  Widget build(BuildContext context) {
    <JavascriptChannel>{_javascriptChannel()};
    var flutterWebViewPlugin;

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
        actions: <Widget>[
          TextButton.icon(
            onPressed: () {
              getLoginChallengeId();
              WebView(
                initialUrl:
                    '${APIMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${APIMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                javascriptMode: JavascriptMode.unrestricted,
                onWebViewCreated: (controller) {
                  _webViewController = controller;
                  controller.reload();
                },
                onProgress: (int progress) {},
                navigationDelegate: (NavigationRequest request) {
                  if (request.url.startsWith('https://www.youtube.com/')) {
                    return NavigationDecision.prevent;
                  }

                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {},
                onPageFinished: (String url) {},
                gestureNavigationEnabled: true,
                backgroundColor: const Color(0x00000000),
              );
              webViewKey.currentState?.reloadWebView();

              _refreshIndicatorKey.currentState?.show();
            },
            icon: const Icon(
              Icons.refresh,
              size: 24.0,
              color: Colors.white,
            ),
            label: const Text(''),
          ),
        ],
      ),
      body: RefreshIndicator(
        key: _refreshIndicatorKey,
        color: Colors.white,
        backgroundColor: Colors.blue,
        strokeWidth: 4.0,
        onRefresh: () async {
          return Future<void>.delayed(const Duration(seconds: 3));
        },
        child: loginId != null
            ? WebView(
                initialUrl:
                    '${APIMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${APIMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                javascriptMode: JavascriptMode.unrestricted,
                onProgress: (int progress) {
                  <JavascriptChannel>{_javascriptChannel()};
                },
                navigationDelegate: (NavigationRequest request) {
                  if (request.url.startsWith(
                      '${APIMode.SERVICE_BASE_URL}/${ConscentInitializer.mClientId}')) {
                    getSessionID(loginId!);

                    return NavigationDecision.prevent;
                  } else if (request.url.startsWith(
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})')) {
                    Navigator.pop(context);
                  }

                  if (request.url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    Navigator.pop(context);
                  }

                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {
                  if (url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    debugPrint('Try');

                    Navigator.pop(context);
                  }
                },
                onPageFinished: (String url) {
                  if (url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    debugPrint('Try');

                    Navigator.pop(context);
                  }
                },
                javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
              )
            : Center(child: CircularProgressIndicator()),
      ),
    );
  }

  void reloadWebView() {
    _webViewController.reload();
  }
}

==> flutter_conscent_plugin-0.1.5.tar.gz: lib/webviews.dart <==
import 'dart:async';
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import '../Model/APIMode.dart';
import 'ConscentInitializer.dart';

void main() {
  runApp(
    MaterialApp(
      home: WebViewApps(isWoman: true),
    ),
  );
}

// ignore: must_be_immutable
class WebViewApps extends StatefulWidget {
  String tiersId;
  bool isWoman;

  WebViewApps({this.tiersId = '', required this.isWoman, super.key});

  @override
  State<WebViewApps> createState() => _WebViewAppStates();
}

class _WebViewAppStates extends State<WebViewApps> {
  String? loginId;
  String ar = "availFreeTrial=true%20";
  late String fn;

  late WebViewController _webViewController;

  final GlobalKey<RefreshIndicatorState> _refreshIndicatorKey =
      GlobalKey<RefreshIndicatorState>();

  final webViewKey = GlobalKey<_WebViewAppStates>();

  @override
  void initState() {
    _refreshIndicatorKey.currentState?.show();

    const Icon(Icons.refresh);
    if (mounted) {
      getLoginChallengeId();
    }

    if (widget.isWoman) {
      fn = ar;
    } else {
      fn = "";
    }

    super.initState();
  }

  dynamic dataMain;

  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      return sessionId;
    }
    return '';
  }

  dynamic dataMains;
  Future<void> getPstss(String sessionId) async {
    final prefs = await SharedPreferences.getInstance();

    sessionId = prefs.getString('sessionId') ?? "sessionId";

    final uri = Uri.parse(
        '${APIMode.BASE_URL}api/v1/subscription/access?sessionId=$sessionId&clientId=${ConscentInitializer.mClientId}');

    var response = await http.get(uri);

    if (response.statusCode == 200) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;

      if (mounted) {
        Navigator.pop(context, {"response": responseString});
      }
    }
  }

  JavascriptChannel _javascriptChannel() {
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          if (message.message == 'loginSuccess') {
            String sessionId = await getSessionID(loginId!);
            getPstss(sessionId);
          } else if (message.message == 'changeplan') {
            Navigator.pop(context);
          }
        });
  }

  @override
  Widget build(BuildContext context) {
    <JavascriptChannel>{_javascriptChannel()};
    // var flutterWebViewPlugin;

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
        actions: <Widget>[
          TextButton.icon(
            onPressed: () {
              getLoginChallengeId();
              WebView(
                initialUrl:
                    '${APIMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${APIMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                javascriptMode: JavascriptMode.unrestricted,
                onWebViewCreated: (controller) {
                  _webViewController = controller;
                  controller.reload();
                },
                onProgress: (int progress) {},
                navigationDelegate: (NavigationRequest request) {
                  if (request.url.startsWith('https://www.youtube.com/')) {
                    return NavigationDecision.prevent;
                  }

                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {},
                onPageFinished: (String url) {},
                gestureNavigationEnabled: true,
                backgroundColor: const Color(0x00000000),
              );
              webViewKey.currentState?.reloadWebView();

              _refreshIndicatorKey.currentState?.show();
            },
            icon: const Icon(
              Icons.refresh,
              size: 24.0,
              color: Colors.white,
            ),
            label: const Text(''),
          ),
        ],
      ),
      body: RefreshIndicator(
        key: _refreshIndicatorKey,
        color: Colors.white,
        backgroundColor: Colors.blue,
        strokeWidth: 4.0,
        onRefresh: () async {
          return Future<void>.delayed(const Duration(seconds: 3));
        },
        child: loginId != null
            ? WebView(
                initialUrl:
                    '${APIMode.SERVICE_BASE_URL}/subscription?tierId=${widget.tiersId}&clientId=${ConscentInitializer.mClientId}&$fn&siteUrl=${APIMode.SERVICE_BASE_URL}&clientContentId=${ConscentInitializer.mContentId}&loginChallenge=$loginId',
                javascriptMode: JavascriptMode.unrestricted,
                onProgress: (int progress) {
                  <JavascriptChannel>{_javascriptChannel()};
                },
                navigationDelegate: (NavigationRequest request) {
                  if (request.url.startsWith(
                      '${APIMode.SERVICE_BASE_URL}/${ConscentInitializer.mClientId}')) {
                    getSessionID(loginId!);

                    return NavigationDecision.prevent;
                  } else if (request.url.startsWith(
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})')) {
                    Navigator.pop(context);
                  }

                  if (request.url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    Navigator.pop(context);
                  }

                  return NavigationDecision.navigate;
                },
                onPageStarted: (String url) {
                  if (url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    debugPrint('Try');

                    Navigator.pop(context);
                  }
                },
                onPageFinished: (String url) {
                  if (url ==
                      '${APIMode.SERVICE_BASE_URL}/?csc-tierId=${widget.tiersId})') {
                    debugPrint('Try');

                    Navigator.pop(context);
                  }
                },
                javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
              )
            : const Center(child: CircularProgressIndicator()),
      ),
    );
  }

  void reloadWebView() {
    _webViewController.reload();
  }
}
